<?php

namespace Bixo\Contractsform\Http\Controllers;

use Exception;
use Litepie\Http\Controllers\ResourceController as BaseController;
use Bixo\Contractsform\Forms\Contract as ContractForm;
use Bixo\Contractsform\Http\Requests\ContractResourceRequest;
use Bixo\Contractsform\Http\Resources\ContractResource;
use Bixo\Contractsform\Http\Resources\ContractsCollection;
use Bixo\Contractsform\Models\Contract;
use Bixo\Contractsform\Actions\ContractAction;
use Bixo\Contractsform\Actions\ContractActions;


/**
 * Resource controller class for contract.
 */
class ContractResourceController extends BaseController
{

    /**
     * Initialize contract resource controller.
     *
     *
     * @return null
     */
    public function __construct()
    {
        parent::__construct();
        $this->middleware(function ($request, $next) {
            $this->form = ContractForm::grouped(false)
                            ->setAttributes()
                            ->toArray();
            $this->modules = $this->modules(config('bixo.contractsform.modules'), 'contractsform', guard_url('contractsform'));
            return $next($request);
        });
    }

    /**
     * Display a list of contract.
     *
     * @return Response
     */
    public function index(ContractResourceRequest $request)
    {
        $request = $request->all();
        $page = ContractActions::run('paginate', $request);

        $data = new ContractsCollection($page);

        $form = $this->form;
        $modules = $this->modules;

        return $this->response->setMetaTitle(trans('contractsform::contract.names'))
            ->view('contractsform::contract.index')
            ->data(compact('data', 'modules', 'form'))
            ->output();

    }

    /**
     * Display contract.
     *
     * @param Request $request
     * @param Model   $contract
     *
     * @return Response
     */
    public function show(ContractResourceRequest $request, Contract $model)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = new ContractResource($model);
        return $this->response
            ->setMetaTitle(trans('app.view') . ' ' . trans('contractsform::contract.name'))
            ->data(compact('data', 'form', 'modules'))
            ->view('contractsform::contract.show')
            ->output();
    }

    /**
     * Show the form for creating a new contract.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(ContractResourceRequest $request, Contract $model)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = new ContractResource($model);
        return $this->response->setMetaTitle(trans('app.new') . ' ' . trans('contractsform::contract.name'))
            ->view('contractsform::contract.create')
            ->data(compact('data', 'form', 'modules'))
            ->output();

    }

    /**
     * Create new contract.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(ContractResourceRequest $request, Contract $model)
    {
        try {
            $request = $request->all();
            $model = ContractAction::run('store', $model, $request);
            $data = new ContractResource($model);
            return $this->response->message(trans('messages.success.created', ['Module' => trans('contractsform::contract.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('contractsform/contract/' . $model->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/contractsform/contract'))
                ->redirect();
        }

    }

    /**
     * Show contract for editing.
     *
     * @param Request $request
     * @param Model   $contract
     *
     * @return Response
     */
    public function edit(ContractResourceRequest $request, Contract $model)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = new ContractResource($model);
        // return view('contractsform::contract.edit', compact('data', 'form', 'modules'));

        return $this->response->setMetaTitle(trans('app.edit') . ' ' . trans('contractsform::contract.name'))
            ->view('contractsform::contract.edit')
            ->data(compact('data', 'form', 'modules'))
            ->output();

    }

    /**
     * Update the contract.
     *
     * @param Request $request
     * @param Model   $contract
     *
     * @return Response
     */
    public function update(ContractResourceRequest $request, Contract $model)
    {
        try {
            $request = $request->all();
            $model = ContractAction::run('update', $model, $request);
            $data = new ContractResource($model);

            return $this->response->message(trans('messages.success.updated', ['Module' => trans('contractsform::contract.name')]))
                ->code(204)
                ->status('success')
                ->data(compact('data'))
                ->url(guard_url('contractsform/contract/' . $model->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('contractsform/contract/' .  $model->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the contract.
     *
     * @param Model   $contract
     *
     * @return Response
     */
    public function destroy(ContractResourceRequest $request, Contract $model)
    {
        try {

            $request = $request->all();
            $model = ContractAction::run('destroy', $model, $request);
            $data = new ContractResource($model);

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('contractsform::contract.name')]))
                ->code(202)
                ->status('success')
                ->data(compact('data'))
                ->url(guard_url('contractsform/contract/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('contractsform/contract/' .  $model->getRouteKey()))
                ->redirect();
        }

    }
}
